.. currentmodule:: jax_cosmo

jax\_cosmo package
==================

.. toctree::
   :maxdepth: 1

   jax_cosmo.angular_cl
   jax_cosmo.background
   jax_cosmo.bias
   jax_cosmo.constants
   jax_cosmo.jax_utils
   jax_cosmo.power
   jax_cosmo.probes
   jax_cosmo.redshift
   jax_cosmo.transfer
   jax_cosmo.utils
